# coding: utf-8
# Copyright (C) 2015 Mark Ma
# Author: Mark Ma <maanyng@yahoo.com.tw>
# License: MIT
# For license information, see LICENSE.TXT

"""
  The nester_pre is an open source Python library for nested data processing. 
  It provided a function to print item of list, whether list is nested or not.
"""


# Copyright notice
__copyright__ = "MIT"

# Maintainer
__maintainer__ = "Mark Ma"
__maintainer_email__ = "maanyng@yahoo.com.tw"
__author__ = __maintainer__
__author_email__ = __maintainer_email__


try:
    #from .file import a_function, b_function
    from .nester_pre import print_lol
    from .nester_pre_version import __version__

except ImportError as e:
    print('Could not import module.: '+ str(e))



from __future__ import print_function
import sys

def print_lol(res, indent = True, level = 0, dest = None):
    '''
    Parameters
    ----------
    res - any python list.
    indent - set the indentation or True by default.    
    level - indent for nested list.(must use with indent parameter)
    dest - set print out destination, or to sys.stdout by default.

    Try it now!    
    '''
  
    if dest == None:
        dest = sys.stdout
    if level < 0:
        indent = False

    if isinstance(res, str) or isinstance(res, int) :
        if sys.version_info < (3, 0):
            print >> dest, res
        print(res, file=dest)
    elif isinstance(res, dict):
        print_lol(printDict(res, level), indent, level+1, dest)

    else:
        for item in res:
            if  isinstance(item, list) or  isinstance(item, tuple):
                print_lol(item, indent, level+1, dest)
            elif  isinstance(item, dict):
                print_lol(item, indent, level+1, dest) 
            else:
                if indent:                
                    for tap_stop in range(level):
                        print("    ",end = '',  file = dest)
                print(item, file = dest)

def printDict(obj_in, level):
    tmp = []
    tmpStr =''
    for key, value in (obj_in.items()):
        if  isinstance(value, list) or isinstance(value, tuple) or isinstance(value, dict):
            for valueItem in value:
                tmpStr += str(valueItem) + ' '
            value = tmpStr
        tmp.append(str(key) + ':  '+ str(value))
        tmpStr=''
    return tmp



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

import nester_pre

setup(
    name = 'nester_pre',
    version = nester_pre.__version__,

    description = 'nester_pre let you print nestered data. i.e. nested list',
    long_description = open('README.rst').read(),

    author ='Mark Ma',
    author_email = 'maanyng@yahoo.com.tw',
    url = 'https://github.com/immark/nester_pre',

    license='MIT',
    platforms = 'any',
    classifiers = [
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],

    packages = find_packages(),

)
